from django.apps import AppConfig


class HxRequestsConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "hx_requests"
